@@ -26,7 +26,7 @@ from mqttwarn.context import RuntimeContext, FunctionInvoker
 from mqttwarn.cron import PeriodicThread
 from mqttwarn.util import \
     load_function, load_module_from_file, load_module_by_name, timeout, \
-    parse_cron_options, sanitize_function_name, Struct, Formatter, asbool, exception_traceback
+    parse_cron_options, sanitize_function_name, Struct, Formatter, asbool
 
 try:
     import json
@@ -155,7 +155,7 @@ def on_connect(mosq, userdata, flags, result_code):
     5: Refused - not authorised (MQTT v3.1 broker only)
     """
     if result_code == 0:
-        logger.debug("Connected to MQTT broker, subscribing to topics...")
+        logger.debug("Connected to MQTT broker, subscribing to topics")
         if not cf.cleansession:
             logger.debug("Cleansession==False; previous subscriptions for clientid %s remain active on broker" % cf.clientid)
 
@@ -195,7 +195,7 @@ def on_disconnect(mosq, userdata, result_code):
     if result_code == 0:
         logger.info("Clean disconnection from broker")
     else:
-        send_failover("brokerdisconnected", "Broker connection lost. Will attempt to reconnect in 5s...")
+        send_failover("brokerdisconnected", "Broker connection lost. Will attempt to reconnect in 5s")
         time.sleep(5)
 
 
@@ -218,7 +218,7 @@ def on_message(mosq, userdata, msg):
         # Get the topic for this section (usually the section name but optionally overridden)
         match_topic = context.get_topic(section)
         if paho.topic_matches_sub(match_topic, topic):
-            logger.debug("Section [%s] matches message on %s. Processing..." % (section, topic))
+            logger.debug("Section [%s] matches message on %s, processing it" % (section, topic))
             # Check for any message filters
             if context.is_filtered(section, topic, payload):
                 logger.debug("Filter in section [%s] has skipped message on %s" % (section, topic))
@@ -319,7 +319,7 @@ def send_to_targets(section, topic, payload):
                 continue
 
         # skip targets with invalid services
-        if not service in service_plugins:
+        if service not in service_plugins:
             logger.error("Invalid configuration: topic '%s' points to non-existing service '%s'" % (topic, service))
             continue
 
@@ -371,13 +371,13 @@ def xform(function, orig_value, transform_data):
             try:
                 res = context.invoker.datamap(function_name, transform_data)
                 return res
-            except Exception as e:
-                logger.warning("Cannot invoke %s(): %s" % (function_name, e))
+            except Exception:
+                logger.exception(f"Invoking function '{function_name}' failed")
 
         try:
             res = Formatter().format(function, **transform_data)
-        except Exception as e:
-            logger.exception("Formatting message failed")
+        except Exception:
+            logger.exception(f"Formatting message with function '{function}' failed")
 
     if isinstance(res, str):
         res = res.replace("\\n", "\n")
@@ -401,7 +401,7 @@ def decode_payload(section, topic, payload):
     # function obtains the topic string as well as the payload and any
     # existing transformation data, and it can do 'things' with all.
     # This is the way it should originally have been, but I can no
-    # longer fix the original ... (legacy)
+    # longer fix the original (legacy).
 
     all_data = context.get_all_data(section, topic, transform_data)
     if all_data is not None and isinstance(all_data, dict):
@@ -439,7 +439,7 @@ def processor(worker_id=None):
 
         # Sanity checks.
         # If service configuration or targets can not be obtained successfully,
-        # log a sensible error message, fail the job and carry on with the next job.
+        # log a sensible error message, fail the job, and carry on with the next job.
         try:
             service_config  = context.get_service_config(service)
             service_targets = context.get_service_targets(service)
@@ -449,8 +449,8 @@ def processor(worker_id=None):
                                 "non-existing target '{target}' in service '{service}'".format(**locals())
                 raise KeyError(error_message)
 
-        except Exception as ex:
-            logger.error("Cannot handle service=%s, target=%s: %s\n%s" % (service, target, ex, exception_traceback()))
+        except Exception:
+            logger.exception(f"Cannot handle service={service}, target={target}")
             q_in.task_done()
             continue
 
@@ -515,8 +515,8 @@ def processor(worker_id=None):
                     service_logger_name = 'mqttwarn.services.{}'.format(service)
                 srv = make_service(mqttc=mqttc, name=service_logger_name)
                 notified = timeout(module.plugin, (srv, st))
-            except Exception as e:
-                logger.exception("Cannot invoke service for `%s'" % service)
+            except Exception:
+                logger.exception(f"Invoking service '{service}' failed")
 
             if not notified:
                 logger.warning("Notification of %s for `%s' FAILED or TIMED OUT" % (service, item.get('topic')))
@@ -525,7 +525,7 @@ def processor(worker_id=None):
 
         q_in.task_done()
 
-    logger.debug("Thread exiting...")
+    logger.debug("Thread exiting")
 
 
 def load_services(services):
@@ -556,8 +556,8 @@ def load_services(services):
                 service_plugins[service]['module'] = load_module_by_name(module)
                 logger.info('Successfully loaded service "{}" from module "{}"'.format(service, module))
                 continue
-            except Exception as ex:
-                logger.exception('Unable to load service "{}" from module "{}": {}'.format(service, module, ex))
+            except Exception:
+                logger.exception('Loading service "{}" from module "{}" failed'.format(service, module))
 
         # Load built-in service module.
         else:
@@ -576,8 +576,8 @@ def load_services(services):
                 service_plugins[service]['module'] = load_module_from_file(modulefile)
                 logger.info('Successfully loaded service "{}"'.format(service))
                 success = True
-            except Exception as ex:
-                logger.exception('Unable to load service "{}" from file "{}": {}'.format(service, modulefile, ex))
+            except Exception:
+                logger.exception(f'Loading service "{service}" from file "{modulefile}" failed')
 
         if not success:
             logger.critical('Unable to load service "{}"'.format(service))
@@ -595,7 +595,7 @@ def connect():
     try:
         services = cf.getlist('defaults', 'launch')
     except:
-        logger.error("No services configured. Aborting")
+        logger.error("No services configured, aborting")
         sys.exit(2)
 
     load_services(services)
@@ -603,7 +603,7 @@ def connect():
     # Initialize MQTT broker connection
     mqttc = paho.Client(cf.clientid, clean_session=cf.cleansession, protocol=cf.protocol)
 
-    logger.debug("Attempting connection to MQTT broker %s:%d..." % (cf.hostname, int(cf.port)))
+    logger.debug("Attempting connection to MQTT broker %s:%d" % (cf.hostname, int(cf.port)))
     mqttc.on_connect = on_connect
     mqttc.on_message = on_message
     mqttc.on_disconnect = on_disconnect
@@ -614,10 +614,10 @@ def connect():
 
     # set the lwt before connecting
     if cf.lwt is not None:
-        logger.debug("Setting LWT to %s..." % (cf.lwt))
+        logger.debug("Setting LWT to %s" % (cf.lwt))
         mqttc.will_set(cf.lwt, payload=LWTDEAD, qos=0, retain=True)
 
-    # Delays will be: 3, 6, 12, 24, 30, 30, ...
+    # Delays will be: 3, 6, 12, 24, 30, 30, etc.
     # mqttc.reconnect_delay_set(delay=3, delay_max=30, exponential_backoff=True)
 
     if cf.tls == True:
@@ -629,8 +629,8 @@ def connect():
     try:
         mqttc.connect(cf.hostname, int(cf.port), 60)
 
-    except Exception as e:
-        logger.error("Cannot connect to MQTT broker at %s:%d: %s" % (cf.hostname, int(cf.port), e))
+    except Exception:
+        logger.exception("Cannot connect to MQTT broker at %s:%d" % (cf.hostname, int(cf.port)))
         sys.exit(2)
 
     # Update our runtime context (used by functions etc) now we have a connected MQTT client
@@ -735,7 +735,7 @@ def cleanup(signum=None, frame=None):
         logger.debug("Cancel %s timer" % ptname)
         ptlist[ptname].cancel()
 
-    logger.debug("Disconnecting from MQTT broker...")
+    logger.debug("Disconnecting from MQTT broker")
     if cf.lwt is not None:
         mqttc.publish(cf.lwt, LWTDEAD, qos=0, retain=True)
     mqttc.loop_stop()
