@@ -4,12 +4,10 @@ from builtins import str
 import os
 import re
 import imp
-import sys
 import json
 import string
-import traceback
 import pkg_resources
-from six import StringIO, string_types
+from six import string_types
 
 try:
     import hashlib
@@ -242,21 +240,3 @@ def load_function(name=None, py_mod=None):
 def get_resource_content(package, filename):
     with pkg_resources.resource_stream(package, filename) as stream:
         return stream.read().decode('utf-8')
-
-
-def exception_traceback(exc_info=None):
-    """
-    Return a string containing a traceback message for the given
-    exc_info tuple (as returned by sys.exc_info()).
-
-    from setuptools.tests.doctest
-    """
-
-    if not exc_info:
-        exc_info = sys.exc_info()
-
-    # Get a traceback message.
-    excout = StringIO()
-    exc_type, exc_val, exc_tb = exc_info
-    traceback.print_exception(exc_type, exc_val, exc_tb, file=excout)
-    return excout.getvalue()
